==> designate_2.1.0.orig.tar.gz: designate-2.1.0/designate/common/config.py <==
# Copyright 2016 Hewlett Packard Enterprise Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from oslo_config import cfg
from oslo_middleware import cors


def set_defaults():
    """Override all default values from upstream packages"""

    # CORS Middleware Defaults
    # TODO(krotscheck): Update with https://review.openstack.org/#/c/285368/
    cfg.set_defaults(cors.CORS_OPTS,
                     allow_headers=['X-Auth-Token',
                                    'X-Auth-Sudo-Tenant-ID',
                                    'X-Auth-Sudo-Project-ID',
                                    'X-Auth-All-Projects',
                                    'X-Designate-Edit-Managed-Records'],
                     expose_headers=['X-OpenStack-Request-ID',
                                     'Host'],
                     allow_methods=['GET',
                                    'PUT',
                                    'POST',
                                    'DELETE',
                                    'PATCH',
                                    'HEAD']
                     )

==> designate_3.0.1.orig.tar.gz: designate-3.0.1/designate/common/config.py <==
# Copyright 2016 Hewlett Packard Enterprise Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from oslo_config import cfg
from oslo_middleware import cors


def set_defaults():
    """Override all default values from upstream packages"""

    # CORS Middleware Defaults
    # TODO(krotscheck): Update with https://review.openstack.org/#/c/285368/
    cfg.set_defaults(cors.CORS_OPTS,
                     allow_headers=['X-Auth-Token',
                                    'X-Auth-Sudo-Tenant-ID',
                                    'X-Auth-Sudo-Project-ID',
                                    'X-Auth-All-Projects',
                                    'X-Designate-Edit-Managed-Records',
                                    'OpenStack-DNS-Hide-Counts'],
                     expose_headers=['X-OpenStack-Request-ID',
                                     'Host'],
                     allow_methods=['GET',
                                    'PUT',
                                    'POST',
                                    'DELETE',
                                    'PATCH',
                                    'HEAD']
                     )
